==> apache-ignite-2.9.0-src.zip: apache-ignite-2.9.0-src/modules/platforms/dotnet/Apache.Ignite.Core.Tests/DisposeAction.cs <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

namespace Apache.Ignite.Core.Tests
{
    using System;
    using Apache.Ignite.Core.Impl.Common;

    /// <summary>
    /// Wraps an action to be executed on Dispose call.
    /// </summary>
    public class DisposeAction : IDisposable
    {
        /** */
        private readonly Action _action;

        /// <summary>
        /// Initializes a new instance of <see cref="DisposeAction"/>.
        /// </summary>
        /// <param name="action">Action.</param>
        public DisposeAction(Action action)
        {
            IgniteArgumentCheck.NotNull(action, "action");
            _action = action;
        }

        /** <inheritdoc /> */
        public void Dispose()
        {
            _action();
        }
    }
}

==> apache-ignite-2.17.0-src.zip: apache-ignite-2.17.0-src/modules/platforms/dotnet/Apache.Ignite.Core.Tests/DisposeAction.cs <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

namespace Apache.Ignite.Core.Tests
{
    using System;
    using Apache.Ignite.Core.Impl.Common;

    /// <summary>
    /// Wraps an action to be executed on Dispose call.
    /// </summary>
    public sealed class DisposeAction : IDisposable
    {
        /** */
        private readonly Action _action;

        /// <summary>
        /// Initializes a new instance of <see cref="DisposeAction"/>.
        /// </summary>
        /// <param name="action">Action.</param>
        public DisposeAction(Action action)
        {
            IgniteArgumentCheck.NotNull(action, "action");
            _action = action;
        }

        /** <inheritdoc /> */
        public void Dispose()
        {
            _action();
        }
    }
}
